summaryrefslogtreecommitdiffstats
path: root/src/gui/widgets/TextFloat.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit3fcef18c75f7cd751ed706c12977230242fb817d (patch)
treea94c2497a3923ed9972e71c5bbba0697882c1427 /src/gui/widgets/TextFloat.cpp
parent80ee419f074dc252449791628d4584b5c0ea0c9b (diff)
downloadrosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.tar.gz
rosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/gui/widgets/TextFloat.cpp')
-rw-r--r--src/gui/widgets/TextFloat.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/widgets/TextFloat.cpp b/src/gui/widgets/TextFloat.cpp
index 5bc9446..d3cc9d5 100644
--- a/src/gui/widgets/TextFloat.cpp
+++ b/src/gui/widgets/TextFloat.cpp
@@ -39,8 +39,8 @@
namespace Rosegarden
{
-TextFloat::TextFloat(TQWidget *tqparent):
- TQWidget(tqparent, "TextFloat",
+TextFloat::TextFloat(TQWidget *parent):
+ TQWidget(parent, "TextFloat",
WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop),
m_text("")
{
@@ -61,9 +61,9 @@ TextFloat::reparent(TQWidget *newParent)
position += newParent->pos();
}
// Position this widget to the right of the tqparent
//
- //move(pos + TQPoint(tqparent->width() + 5, 5));
+ //move(pos + TQPoint(parent->width() + 5, 5));
TQWidget::reparent(newParent,
WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop,
@@ -61,9 +61,9 @@ TextFloat::reparent(TQWidget *newParent)
position += newParent->pos();
}
- // Position this widget to the right of the tqparent
+ // Position this widget to the right of the parent
//